[jbosscache-commits] JBoss Cache SVN: r8165 - in core/trunk/src: main/java/org/jboss/cache/config/parsing and 6 other directories.

jbosscache-commits at lists.jboss.org jbosscache-commits at lists.jboss.org
Fri Aug 7 06:03:28 EDT 2009


Author: manik.surtani at jboss.com
Date: 2009-08-07 06:03:27 -0400 (Fri, 07 Aug 2009)
New Revision: 8165

Added:
   core/trunk/src/main/resources/schema/jbosscache-config-3.2.xsd
   core/trunk/src/main/resources/schema/jbosscache-registry-3.2.xsd
Modified:
   core/trunk/src/main/docbook/userguide/en/modules/configuration.xml
   core/trunk/src/main/docbook/userguide/en/modules/configuration_reference.xml
   core/trunk/src/main/java/org/jboss/cache/config/parsing/RootElementBuilder.java
   core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlConfigHelper.java
   core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlConfigurationParser.java
   core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlParserBase.java
   core/trunk/src/main/java/org/jboss/cache/config/parsing/element/BuddyElementParser.java
   core/trunk/src/main/java/org/jboss/cache/config/parsing/element/CustomInterceptorsElementParser.java
   core/trunk/src/main/java/org/jboss/cache/config/parsing/element/EvictionElementParser.java
   core/trunk/src/main/java/org/jboss/cache/config/parsing/element/LoadersElementParser.java
   core/trunk/src/main/resources/config-samples/all.xml
   core/trunk/src/main/resources/config-samples/buddy-replication.xml
   core/trunk/src/main/resources/config-samples/cacheloader-enabled.xml
   core/trunk/src/main/resources/config-samples/eviction-enabled.xml
   core/trunk/src/main/resources/config-samples/external-jgroups-file.xml
   core/trunk/src/main/resources/config-samples/invalidation-async.xml
   core/trunk/src/main/resources/config-samples/local.xml
   core/trunk/src/main/resources/config-samples/multiplexer-enabled.xml
   core/trunk/src/main/resources/config-samples/non-blocking-state-transfer.xml
   core/trunk/src/main/resources/config-samples/string-property-replaced.xml
   core/trunk/src/main/resources/config-samples/total-replication.xml
   core/trunk/src/main/resources/config2to3.xslt
   core/trunk/src/test/resources/configs/buddy-replication-cache.xml
   core/trunk/src/test/resources/configs/clonable-config.xml
   core/trunk/src/test/resources/configs/local-lru-eviction.xml
   core/trunk/src/test/resources/configs/local-passivation.xml
   core/trunk/src/test/resources/configs/local-tx.xml
   core/trunk/src/test/resources/configs/mixedPolicy-eviction.xml
   core/trunk/src/test/resources/configs/mux.xml
   core/trunk/src/test/resources/configs/mvcc-repl-sync-br.xml
   core/trunk/src/test/resources/configs/parser-test-async.xml
   core/trunk/src/test/resources/configs/parser-test.xml
   core/trunk/src/test/resources/configs/policyPerRegion-eviction.xml
   core/trunk/src/test/resources/configs/replSync.xml
   core/trunk/src/test/resources/configs/string-property-replaced.xml
   core/trunk/src/test/resources/jbc3-registry-configs.xml
   core/trunk/src/test/resources/unit-test-cache-service.xml
Log:
Updated version on config schema and sample files, docs.  Also made schema version management simpler in XML parsers

Modified: core/trunk/src/main/docbook/userguide/en/modules/configuration.xml
===================================================================
--- core/trunk/src/main/docbook/userguide/en/modules/configuration.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/docbook/userguide/en/modules/configuration.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -51,7 +51,7 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
 <jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-            xmlns="urn:jboss:jbosscache-core:config:3.1">
+            xmlns="urn:jboss:jbosscache-core:config:3.2">
 </jbosscache>
 
 

Modified: core/trunk/src/main/docbook/userguide/en/modules/configuration_reference.xml
===================================================================
--- core/trunk/src/main/docbook/userguide/en/modules/configuration_reference.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/docbook/userguide/en/modules/configuration_reference.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -10,7 +10,7 @@
       <programlisting role="XML"><![CDATA[
 <?xml version="1.0" encoding="UTF-8"?>
 
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
 
    <!--
@@ -335,8 +335,8 @@
                <row>
                   <entry><emphasis role="bold">xmlns</emphasis></entry>
                   <entry> - </entry>
-                  <entry>urn:jboss:jbosscache-core:config:3.1</entry>
-                  <entry>urn:jboss:jbosscache-core:config:3.1</entry>
+                  <entry>urn:jboss:jbosscache-core:config:3.2</entry>
+                  <entry>urn:jboss:jbosscache-core:config:3.2</entry>
                   <entry>Defines the XML namespace for all configuration entries.</entry>
                </row>
                <row>

Modified: core/trunk/src/main/java/org/jboss/cache/config/parsing/RootElementBuilder.java
===================================================================
--- core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlConfigHelper.java	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlConfigHelper.java	2009-08-07 10:03:27 UTC (rev 8165)
@@ -391,7 +391,7 @@
     */
    public static Element stringToElementInCoreNS(String xml) throws Exception
    {
-      xml = "<wrapper xmlns='" + RootElementBuilder.JBOSSCACHE_CORE_NS_31 + "'>" + xml + "</wrapper>";
+      xml = "<wrapper xmlns='" + RootElementBuilder.DEFAULT_CORE_NS + "'>" + xml + "</wrapper>";
       ByteArrayInputStream bais = new ByteArrayInputStream(xml.getBytes("utf8"));
       DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
       factory.setNamespaceAware(true);

Modified: core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlConfigurationParser.java
===================================================================
--- core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlConfigurationParser.java	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlConfigurationParser.java	2009-08-07 10:03:27 UTC (rev 8165)
@@ -31,7 +31,6 @@
 import org.jboss.cache.config.parsing.element.CustomInterceptorsElementParser;
 import org.jboss.cache.config.parsing.element.EvictionElementParser;
 import org.jboss.cache.config.parsing.element.LoadersElementParser;
-import org.jboss.cache.config.parsing.JGroupsStackParser;
 import org.jboss.cache.lock.IsolationLevel;
 import org.jboss.cache.util.FileLookup;
 import org.w3c.dom.Element;
@@ -144,16 +143,14 @@
    private Configuration processElements(boolean ignoreRoot)
    {
       coreNamespace = root.getNamespaceURI();
-      if (coreNamespace == null) coreNamespace = RootElementBuilder.JBOSSCACHE_CORE_NS_31; // use the default
+      if (coreNamespace == null) coreNamespace = RootElementBuilder.DEFAULT_CORE_NS; // use the default
       
       if (!ignoreRoot &&
-            (!"jbosscache".equals(root.getLocalName()) ||
-             (!RootElementBuilder.JBOSSCACHE_CORE_NS_31.equals(coreNamespace) &&
-             !RootElementBuilder.JBOSSCACHE_CORE_NS_30.equals(coreNamespace))
-         ))
+            (!"jbosscache".equals(root.getLocalName()) || !isAllowedCoreNamespace(coreNamespace))
+         )
       {
-            throw new ConfigurationException("Expected root element <jbosscache />" + (isValidating() ? " in either {" +
-                  RootElementBuilder.JBOSSCACHE_CORE_NS_30 + "} or {" + RootElementBuilder.JBOSSCACHE_CORE_NS_31 + "} namespaces" : ""));
+            throw new ConfigurationException("Expected root element <jbosscache />" + (isValidating() ? " in either of " + getAllowedCoreNamespaces()
+                  + " namespaces" : ""));
       }
 
       try

Modified: core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlParserBase.java
===================================================================
--- core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlParserBase.java	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlParserBase.java	2009-08-07 10:03:27 UTC (rev 8165)
@@ -22,10 +22,13 @@
 package org.jboss.cache.config.parsing;
 
 import org.jboss.cache.config.LegacyConfigurationException;
+import org.jboss.cache.util.Immutables;
 import org.jboss.util.StringPropertyReplacer;
 import org.w3c.dom.Element;
 import org.w3c.dom.NodeList;
 
+import java.util.List;
+
 /**
  * Contains utility methods that might be useful to most of the parsers.
  *
@@ -107,4 +110,16 @@
       String name = e.getNodeName();
       if ("config".equals(name)) throw new LegacyConfigurationException("Legacy element encountered when using parser " + getClass().getSimpleName());
    }
+
+   protected boolean isAllowedCoreNamespace(String namespace) {
+      for (String ns: RootElementBuilder.ALLOWED_CORE_NAMESPACES.keySet())
+      {
+         if (ns.equals(namespace)) return true;
+      }
+      return false;
+   }
+
+   protected List<String> getAllowedCoreNamespaces() {
+      return Immutables.immutableListConvert(RootElementBuilder.ALLOWED_CORE_NAMESPACES.keySet());
+   }
 }

Modified: core/trunk/src/main/java/org/jboss/cache/config/parsing/element/BuddyElementParser.java
===================================================================
--- core/trunk/src/main/java/org/jboss/cache/config/parsing/element/BuddyElementParser.java	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/java/org/jboss/cache/config/parsing/element/BuddyElementParser.java	2009-08-07 10:03:27 UTC (rev 8165)
@@ -44,7 +44,7 @@
 {
    public BuddyElementParser()
    {
-      this(RootElementBuilder.JBOSSCACHE_CORE_NS_31);
+      this(RootElementBuilder.DEFAULT_CORE_NS);
    }
 
    public BuddyElementParser(String coreNamespace)

Modified: core/trunk/src/main/java/org/jboss/cache/config/parsing/element/CustomInterceptorsElementParser.java
===================================================================
--- core/trunk/src/main/java/org/jboss/cache/config/parsing/element/CustomInterceptorsElementParser.java	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/java/org/jboss/cache/config/parsing/element/CustomInterceptorsElementParser.java	2009-08-07 10:03:27 UTC (rev 8165)
@@ -49,7 +49,7 @@
 {
    public CustomInterceptorsElementParser()
    {
-      this(RootElementBuilder.JBOSSCACHE_CORE_NS_31);
+      this(RootElementBuilder.DEFAULT_CORE_NS);
    }
 
    public CustomInterceptorsElementParser(String coreNamespace)

Modified: core/trunk/src/main/java/org/jboss/cache/config/parsing/element/EvictionElementParser.java
===================================================================
--- core/trunk/src/main/java/org/jboss/cache/config/parsing/element/EvictionElementParser.java	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/java/org/jboss/cache/config/parsing/element/EvictionElementParser.java	2009-08-07 10:03:27 UTC (rev 8165)
@@ -52,7 +52,7 @@
 {
    public EvictionElementParser()
    {
-      this(RootElementBuilder.JBOSSCACHE_CORE_NS_31);
+      this(RootElementBuilder.DEFAULT_CORE_NS);
    }
 
    public EvictionElementParser(String coreNamespace)

Modified: core/trunk/src/main/java/org/jboss/cache/config/parsing/element/LoadersElementParser.java
===================================================================
--- core/trunk/src/main/java/org/jboss/cache/config/parsing/element/LoadersElementParser.java	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/java/org/jboss/cache/config/parsing/element/LoadersElementParser.java	2009-08-07 10:03:27 UTC (rev 8165)
@@ -45,7 +45,7 @@
 {
    public LoadersElementParser()
    {
-      this(RootElementBuilder.JBOSSCACHE_CORE_NS_31);
+      this(RootElementBuilder.DEFAULT_CORE_NS);
    }
 
    public LoadersElementParser(String coreNamespace)

Modified: core/trunk/src/main/resources/config-samples/all.xml
===================================================================
--- core/trunk/src/main/resources/config-samples/all.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config-samples/all.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
 
     <!--

Modified: core/trunk/src/main/resources/config-samples/buddy-replication.xml
===================================================================
--- core/trunk/src/main/resources/config-samples/buddy-replication.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config-samples/buddy-replication.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>
 

Modified: core/trunk/src/main/resources/config-samples/cacheloader-enabled.xml
===================================================================
--- core/trunk/src/main/resources/config-samples/cacheloader-enabled.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config-samples/cacheloader-enabled.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
     <!-- Configure the TransactionManager -->
     <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>

Modified: core/trunk/src/main/resources/config-samples/eviction-enabled.xml
===================================================================
--- core/trunk/src/main/resources/config-samples/eviction-enabled.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config-samples/eviction-enabled.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <!-- Configure the TransactionManager -->
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>

Modified: core/trunk/src/main/resources/config-samples/external-jgroups-file.xml
===================================================================
--- core/trunk/src/main/resources/config-samples/external-jgroups-file.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config-samples/external-jgroups-file.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <!-- Configure the TransactionManager -->
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>

Modified: core/trunk/src/main/resources/config-samples/invalidation-async.xml
===================================================================
--- core/trunk/src/main/resources/config-samples/invalidation-async.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config-samples/invalidation-async.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <!-- Configure the TransactionManager -->
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>

Modified: core/trunk/src/main/resources/config-samples/local.xml
===================================================================
--- core/trunk/src/main/resources/config-samples/local.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config-samples/local.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <!-- By not specifying the 'clustering' element, the cache runs in LOCAL mode. -->
    <!-- Configure the TransactionManager -->

Modified: core/trunk/src/main/resources/config-samples/multiplexer-enabled.xml
===================================================================
--- core/trunk/src/main/resources/config-samples/multiplexer-enabled.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config-samples/multiplexer-enabled.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <!-- Configure the TransactionManager -->
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>

Modified: core/trunk/src/main/resources/config-samples/non-blocking-state-transfer.xml
===================================================================
--- core/trunk/src/main/resources/config-samples/non-blocking-state-transfer.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config-samples/non-blocking-state-transfer.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
    <clustering mode="replication">
       <sync />
       <stateRetrieval fetchInMemoryState="true" nonBlocking="true" timeout="60000" />

Modified: core/trunk/src/main/resources/config-samples/string-property-replaced.xml
===================================================================
--- core/trunk/src/main/resources/config-samples/string-property-replaced.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config-samples/string-property-replaced.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <locking lockAcquisitionTimeout="${test.property.LockAcquisitionTimeout:15000}"
             nodeLockingScheme="${test.property.NodeLockingScheme:MVCC}"/>

Modified: core/trunk/src/main/resources/config-samples/total-replication.xml
===================================================================
--- core/trunk/src/main/resources/config-samples/total-replication.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config-samples/total-replication.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <!-- Configure the TransactionManager -->
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>

Modified: core/trunk/src/main/resources/config2to3.xslt
===================================================================
--- core/trunk/src/main/resources/config2to3.xslt	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/resources/config2to3.xslt	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
-<xsl:stylesheet xmlns="urn:jboss:jbosscache-core:config:3.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
+<xsl:stylesheet xmlns="urn:jboss:jbosscache-core:config:3.2" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="xml" indent="yes" version="1.0" encoding="UTF-8" omit-xml-declaration="no"/>
  <xsl:template match="/">
     <xsl:element name="jbosscache">

Copied: core/trunk/src/main/resources/schema/jbosscache-config-3.2.xsd (from rev 8163, core/trunk/src/main/resources/schema/jbosscache-config-3.1.xsd)
===================================================================
--- core/trunk/src/main/resources/schema/jbosscache-config-3.2.xsd	                        (rev 0)
+++ core/trunk/src/main/resources/schema/jbosscache-config-3.2.xsd	2009-08-07 10:03:27 UTC (rev 8165)
@@ -0,0 +1,263 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<xs:schema attributeFormDefault="unqualified" elementFormDefault="qualified"
+           xmlns:tns="urn:jboss:jbosscache-core:config:3.2" targetNamespace="urn:jboss:jbosscache-core:config:3.2"
+           xmlns:xs="http://www.w3.org/2001/XMLSchema" version="1.0">
+
+   <xs:element name="jbosscache" type="tns:cacheConfigurationType"/>
+
+   <xs:complexType name="cacheConfigurationType">
+      <xs:all>
+         <xs:element name="locking" type="tns:lockingType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="transaction" type="tns:transactionType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="startup" type="tns:startupType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="shutdown" type="tns:shutdownType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="serialization" type="tns:serializationType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="jmxStatistics" type="tns:jmxStatisticsType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="listeners" type="tns:listenersType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="invocationBatching" type="tns:invocationBatchingType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="eviction" type="tns:evictionType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="loaders" type="tns:loadersType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="customInterceptors" type="tns:customInterceptorsType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="clustering" type="tns:clusteringType" minOccurs="0" maxOccurs="1"/>
+      </xs:all>
+   </xs:complexType>
+
+   <xs:complexType name="clusteringType">
+      <xs:all>         
+         <xs:element name="sync" type="tns:syncType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="async" type="tns:asyncType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="stateRetrieval" type="tns:stateRetrievalType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="buddy" minOccurs="0" maxOccurs="1">
+            <xs:complexType>
+               <xs:all minOccurs="0">
+                  <xs:element name="dataGravitation" maxOccurs="1">
+                     <xs:complexType>
+                        <xs:attribute name="auto" type="tns:booleanType"/>
+                        <xs:attribute name="removeOnFind" type="tns:booleanType"/>
+                        <xs:attribute name="searchBackupTrees" type="tns:booleanType"/>
+                     </xs:complexType>
+                  </xs:element>
+                  <xs:element name="locator" maxOccurs="1">
+                     <xs:complexType>
+                        <xs:all>
+                           <xs:element name="properties" type="xs:string" maxOccurs="1"/>
+                        </xs:all>
+                        <xs:attribute name="class" type="xs:string"/>
+                     </xs:complexType>
+                  </xs:element>
+               </xs:all>
+               <xs:attribute name="enabled" type="tns:booleanType"/>
+               <xs:attribute name="poolName" type="xs:string"/>
+               <xs:attribute name="communicationTimeout" type="xs:integer"/>
+            </xs:complexType>
+         </xs:element>
+         <xs:element name="jgroupsConfig" type="tns:jgroupsConfigType" minOccurs="0" maxOccurs="1"/>
+      </xs:all>
+      <xs:attribute name="mode">
+         <xs:simpleType>
+            <xs:restriction base="xs:string">
+               <xs:pattern
+                     value="[Rr][Ee][Pp][Ll][Ii][Cc][Aa][Tt][Ii][Oo][Nn]|[Ii][Nn][Vv][Aa][Ll][Ii][Dd][Aa][Tt][Ii][Oo][Nn]|[Rr]|[Ii]|\$\{.*\}"/>
+            </xs:restriction>
+         </xs:simpleType>
+      </xs:attribute>
+      <xs:attribute name="clusterName" type="xs:string" />
+
+
+   </xs:complexType>
+   
+   <xs:complexType name="lockingType">
+      <xs:attribute name="isolationLevel">
+         <xs:simpleType>
+            <xs:restriction base="xs:string">
+               <xs:pattern
+                     value="[Ss][Ee][Rr][Ii][Aa][Ll][Ii][Zz][Aa][Bb][Ll][Ee]|[Rr][Ee][Pp][Ee][Aa][Tt][Aa][Bb][Ll][Ee]_[Rr][Ee][Aa][Dd]|[Rr][Ee][Aa][Dd]_[Cc][Oo][Mm][Mm][Ii][Tt][Tt][Ee][Dd]|[Nn][Oo][Nn][Ee]|\$\{.*\}"/>
+            </xs:restriction>
+         </xs:simpleType>
+      </xs:attribute>
+      <xs:attribute name="lockParentForChildInsertRemove" type="tns:booleanType"/>
+      <xs:attribute name="lockAcquisitionTimeout" type="tns:positiveInteger"/>
+      <xs:attribute name="nodeLockingScheme">
+         <xs:simpleType>
+            <xs:restriction base="xs:string">
+               <xs:pattern
+                     value="[Mm][Vv][Cc][Cc]|[Oo][Pp][Tt][Ii][Mm][Ii][Ss][Tt][Ii][Cc]|[Pp][Ee][Ss][Ss][Ii][Mm][Ii][Ss][Tt][Ii][Cc]|\$\{.*\}"/>
+            </xs:restriction>
+         </xs:simpleType>
+      </xs:attribute>
+      <xs:attribute name="writeSkewCheck" type="tns:booleanType"/>
+      <xs:attribute name="useLockStriping" type="tns:booleanType"/>
+      <xs:attribute name="concurrencyLevel" type="xs:integer"/>
+   </xs:complexType>
+
+   <xs:complexType name="transactionType">
+      <xs:attribute name="transactionManagerLookupClass" type="xs:string"/>
+      <xs:attribute name="syncRollbackPhase" type="tns:booleanType"/>
+      <xs:attribute name="syncCommitPhase" type="tns:booleanType"/>
+   </xs:complexType>
+
+   <xs:complexType name="startupType">
+      <xs:attribute name="regionsInactiveOnStartup" type="tns:booleanType"/>
+   </xs:complexType>
+
+   <xs:complexType name="stateRetrievalType">
+      <xs:attribute name="fetchInMemoryState" type="tns:booleanType"/>
+      <xs:attribute name="timeout" type="tns:positiveInteger"/>
+      <xs:attribute name="nonBlocking" type="tns:booleanType" />
+   </xs:complexType>
+
+   <xs:complexType name="shutdownType">
+      <xs:attribute name="hookBehavior">
+         <xs:simpleType>
+            <xs:restriction base="xs:string">
+               <xs:pattern
+                     value="[Dd][Ee][Ff][Aa][Uu][Ll][Tt]|[Rr][Ee][Gg][Ii][Ss][Tt][Ee][Rr]|[Dd][Oo][Nn][Tt]_[Rr][Ee][Gg][Ii][Ss][Tt][Ee][Rr]|\$\{.*\}"/>
+            </xs:restriction>
+         </xs:simpleType>
+      </xs:attribute>
+   </xs:complexType>
+
+   <xs:complexType name="serializationType">
+      <xs:attribute name="objectInputStreamPoolSize" type="tns:positiveInteger"/>
+      <xs:attribute name="objectOutputStreamPoolSize" type="tns:positiveInteger"/>
+      <xs:attribute name="version" type="xs:string"/>
+      <xs:attribute name="marshallerClass" type="xs:string"/>
+      <xs:attribute name="useLazyDeserialization" type="tns:booleanType"/>
+      <xs:attribute name="useRegionBasedMarshalling" type="tns:booleanType"/>
+   </xs:complexType>
+
+   <xs:simpleType name="booleanType">
+      <xs:restriction base="xs:string">
+         <xs:pattern value="\$\{.*\}|[Tt][Rr][Uu][Ee]|[Ff][Aa][Ll][Ss][Ee]"/>
+      </xs:restriction>
+   </xs:simpleType>
+
+   <xs:simpleType name="positiveInteger">
+      <xs:restriction base="xs:string">
+         <xs:pattern value="\$\{.*\}|\+?[0-9]*"/>
+      </xs:restriction>
+   </xs:simpleType>
+
+   <xs:complexType name="jmxStatisticsType">
+      <xs:attribute name="enabled" type="tns:booleanType"/>
+   </xs:complexType>
+
+   <xs:complexType name="listenersType">
+      <xs:attribute name="asyncPoolSize" type="tns:positiveInteger"/>
+      <xs:attribute name="asyncQueueSize" type="tns:positiveInteger"/>
+   </xs:complexType>
+
+   <xs:complexType name="invocationBatchingType">
+      <xs:attribute name="enabled" type="tns:booleanType"/>
+   </xs:complexType>
+
+   <xs:complexType name="jgroupsConfigType">
+      <xs:sequence>
+         <xs:any processContents="lax" minOccurs="0" maxOccurs="unbounded"/>
+      </xs:sequence>
+      <xs:attribute name="configFile" type="xs:string"/>
+      <xs:attribute name="multiplexerStack" type="xs:string"/>
+   </xs:complexType>
+
+   <xs:complexType name="syncType">
+      <xs:attribute name="replTimeout" type="tns:positiveInteger"/>
+   </xs:complexType>
+
+   <xs:complexType name="asyncType">
+      <xs:attribute name="useReplQueue" type="tns:booleanType"/>
+      <xs:attribute name="replQueueInterval" type="tns:positiveInteger"/>
+      <xs:attribute name="replQueueMaxElements" type="tns:positiveInteger"/>
+      <xs:attribute name="serializationExecutorPoolSize" type="tns:positiveInteger"/>
+      <xs:attribute name="serializationExecutorQueueSize" type="tns:positiveInteger"/>
+   </xs:complexType>
+
+   <xs:complexType name="evictionType">
+      <xs:sequence>
+         <xs:element name="default" type="tns:evictionRegionType" minOccurs="0" maxOccurs="1"/>
+         <xs:element name="region" minOccurs="0" maxOccurs="unbounded" type="tns:evictionRegionType"/>
+      </xs:sequence>
+      <xs:attribute name="wakeUpInterval" type="tns:positiveInteger" use="required"/>
+   </xs:complexType>
+
+   <xs:complexType name="evictionRegionType">
+      <xs:sequence>
+         <xs:element name="property" minOccurs="0" maxOccurs="unbounded" type="tns:propertyType"/>
+      </xs:sequence>
+      <xs:attribute name="name" type="xs:string"/>
+      <xs:attribute name="algorithmClass" type="xs:string"/>
+      <xs:attribute name="actionPolicyClass" type="xs:string"/>
+      <xs:attribute name="eventQueueSize" type="tns:positiveInteger"/>
+   </xs:complexType>
+
+   <xs:complexType name="loadersType">
+      <xs:sequence>
+         <xs:element name="preload" minOccurs="0" maxOccurs="1">
+            <xs:complexType>
+               <xs:sequence>
+                  <xs:element name="node" maxOccurs="unbounded">
+                     <xs:complexType>
+                        <xs:attribute name="fqn" type="xs:string"/>
+                     </xs:complexType>
+                  </xs:element>
+               </xs:sequence>
+            </xs:complexType>
+         </xs:element>
+         <xs:element name="loader" maxOccurs="unbounded">
+            <xs:complexType>
+               <xs:all>
+                  <xs:element name="properties"/>
+                  <xs:element name="singletonStore" minOccurs="0" maxOccurs="1">
+                     <xs:complexType>
+                        <xs:all>
+                           <xs:element name="properties" type="xs:string" minOccurs="0" maxOccurs="1"/>
+                        </xs:all>
+                        <xs:attribute name="enabled" type="tns:booleanType"/>
+                        <xs:attribute name="class" type="xs:string"/>
+                     </xs:complexType>
+                  </xs:element>
+               </xs:all>
+               <xs:attribute name="class" type="xs:string"/>
+               <xs:attribute name="async" type="tns:booleanType"/>
+               <xs:attribute name="fetchPersistentState" type="tns:booleanType"/>
+               <xs:attribute name="ignoreModifications" type="tns:booleanType"/>
+               <xs:attribute name="purgeOnStartup" type="tns:booleanType"/>
+            </xs:complexType>
+         </xs:element>
+      </xs:sequence>
+      <xs:attribute name="passivation" type="tns:booleanType"/>
+      <xs:attribute name="shared" type="tns:booleanType"/>
+   </xs:complexType>
+
+   <xs:complexType name="customInterceptorsType">
+      <xs:sequence>
+         <xs:element name="interceptor" maxOccurs="unbounded">
+            <xs:complexType>
+               <xs:sequence>
+                  <xs:element name="property" maxOccurs="unbounded" type="tns:propertyType" minOccurs="0"/>
+               </xs:sequence>
+               <xs:attribute name="class" type="xs:string"/>
+               <xs:attribute name="position">
+                  <xs:simpleType>
+                     <xs:restriction base="xs:string">
+                        <xs:pattern value="[Ff][Ii][Rr][Ss][Tt]|[Ll][Aa][Ss][Tt]"/>
+                     </xs:restriction>
+                  </xs:simpleType>
+               </xs:attribute>
+               <xs:attribute name="before" type="xs:string"/>
+               <xs:attribute name="after" type="xs:string"/>
+               <xs:attribute name="index" type="tns:positiveInteger"/>
+            </xs:complexType>
+         </xs:element>
+      </xs:sequence>
+   </xs:complexType>
+
+   <xs:complexType name="propertyType">
+      <xs:simpleContent>
+         <xs:extension base="xs:string">
+            <xs:attribute name="name" type="xs:string"/>
+            <xs:attribute name="value" type="xs:string"/>
+         </xs:extension>
+      </xs:simpleContent>
+   </xs:complexType>
+</xs:schema>
+

Copied: core/trunk/src/main/resources/schema/jbosscache-registry-3.2.xsd (from rev 8163, core/trunk/src/main/resources/schema/jbosscache-registry-3.1.xsd)
===================================================================
--- core/trunk/src/main/resources/schema/jbosscache-registry-3.2.xsd	                        (rev 0)
+++ core/trunk/src/main/resources/schema/jbosscache-registry-3.2.xsd	2009-08-07 10:03:27 UTC (rev 8165)
@@ -0,0 +1,24 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<xs:schema attributeFormDefault="unqualified" elementFormDefault="qualified"
+           xmlns:tns="urn:jboss:jbosscache-core:config:3.2"
+           xmlns:repo="urn:jboss:jbosscache-core:cache-repo:3.2"
+           targetNamespace="urn:jboss:jbosscache-core:cache-repo:3.2"
+           xmlns:xs="http://www.w3.org/2001/XMLSchema" version="1.0">
+   <xs:import schemaLocation="jbosscache-config-3.2.xsd" namespace="urn:jboss:jbosscache-core:config:3.2"/>
+
+   <xs:element name="cache-configs">
+      <xs:complexType>
+         <xs:sequence>
+            <xs:element name="cache-config" type="repo:cacheConfig" minOccurs="1" maxOccurs="unbounded"/>
+         </xs:sequence>
+      </xs:complexType>
+   </xs:element>
+
+   <xs:complexType name="cacheConfig">                                                                                                                                                      
+      <xs:complexContent>
+         <xs:extension base="tns:cacheConfigurationType" xml:space="default">
+            <xs:attribute name="name" type="xs:string"/>
+         </xs:extension>
+      </xs:complexContent>
+   </xs:complexType>
+</xs:schema>

Modified: core/trunk/src/test/resources/configs/buddy-replication-cache.xml
===================================================================
--- core/trunk/src/test/resources/configs/buddy-replication-cache.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/buddy-replication-cache.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
 <jbosscache  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-      xmlns="urn:jboss:jbosscache-core:config:3.1">
+      xmlns="urn:jboss:jbosscache-core:config:3.2">
    <locking isolationLevel="REPEATABLE_READ" lockAcquisitionTimeout="10000"/>
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>
    <clustering clusterName="JBossCache-Cluster">

Modified: core/trunk/src/test/resources/configs/clonable-config.xml
===================================================================
--- core/trunk/src/test/resources/configs/clonable-config.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/clonable-config.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-            xmlns="urn:jboss:jbosscache-core:config:3.1">
+            xmlns="urn:jboss:jbosscache-core:config:3.2">
    <locking isolationLevel="SERIALIZABLE" lockAcquisitionTimeout="1" nodeLockingScheme="optimistic"/>
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>
    <clustering clusterName="CloneCluster">

Modified: core/trunk/src/test/resources/configs/local-lru-eviction.xml
===================================================================
--- core/trunk/src/test/resources/configs/local-lru-eviction.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/local-lru-eviction.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <jbosscache  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-      xmlns="urn:jboss:jbosscache-core:config:3.1">
+      xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <locking isolationLevel="REPEATABLE_READ" lockAcquisitionTimeout="15000"/>
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>

Modified: core/trunk/src/test/resources/configs/local-passivation.xml
===================================================================
--- core/trunk/src/test/resources/configs/local-passivation.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/local-passivation.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <jbosscache  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-      xmlns="urn:jboss:jbosscache-core:config:3.1">
+      xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <locking isolationLevel="REPEATABLE_READ" lockAcquisitionTimeout="15000"/>
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>

Modified: core/trunk/src/test/resources/configs/local-tx.xml
===================================================================
--- core/trunk/src/test/resources/configs/local-tx.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/local-tx.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <jbosscache  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-      xmlns="urn:jboss:jbosscache-core:config:3.1">
+      xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <locking isolationLevel="REPEATABLE_READ" lockAcquisitionTimeout="15000"/>
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>

Modified: core/trunk/src/test/resources/configs/mixedPolicy-eviction.xml
===================================================================
--- core/trunk/src/test/resources/configs/mixedPolicy-eviction.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/mixedPolicy-eviction.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <jbosscache  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-      xmlns="urn:jboss:jbosscache-core:config:3.1">
+      xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <locking isolationLevel="REPEATABLE_READ" lockAcquisitionTimeout="15000"/>
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>

Modified: core/trunk/src/test/resources/configs/mux.xml
===================================================================
--- core/trunk/src/test/resources/configs/mux.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/mux.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<jbosscache  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>
    <clustering>
       <stateRetrieval timeout="20000"/>

Modified: core/trunk/src/test/resources/configs/mvcc-repl-sync-br.xml
===================================================================
--- core/trunk/src/test/resources/configs/mvcc-repl-sync-br.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/mvcc-repl-sync-br.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<jbosscache xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns="urn:jboss:jbosscache-core:config:3.2">
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>
    <clustering>
       <stateRetrieval fetchInMemoryState="false"/>

Modified: core/trunk/src/test/resources/configs/parser-test-async.xml
===================================================================
--- core/trunk/src/test/resources/configs/parser-test-async.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/parser-test-async.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -3,7 +3,7 @@
 <!-- file used for functional test of the xml parser -->
 
 <jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-            xmlns="urn:jboss:jbosscache-core:config:3.1">
+            xmlns="urn:jboss:jbosscache-core:config:3.2">
 
 
    <locking isolationLevel="REPEATABLE_READ" lockParentForChildInsertRemove="true" lockAcquisitionTimeout="10234"

Modified: core/trunk/src/test/resources/configs/parser-test.xml
===================================================================
--- core/trunk/src/test/resources/configs/parser-test.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/parser-test.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -3,7 +3,7 @@
 <!-- file used for functional test of the xml parser -->
 
 <jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-            xmlns="urn:jboss:jbosscache-core:config:3.1">
+            xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <!-- perCache -> differrent EntryFactory-->
    <locking isolationLevel="REPEATABLE_READ" lockParentForChildInsertRemove="true" lockAcquisitionTimeout="10234"

Modified: core/trunk/src/test/resources/configs/policyPerRegion-eviction.xml
===================================================================
--- core/trunk/src/test/resources/configs/policyPerRegion-eviction.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/policyPerRegion-eviction.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<jbosscache  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>
    <clustering clusterName="JBossCache-Cluster123" />
    <eviction wakeUpInterval="5000">

Modified: core/trunk/src/test/resources/configs/replSync.xml
===================================================================
--- core/trunk/src/test/resources/configs/replSync.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/replSync.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<jbosscache  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>
    <serialization useRegionBasedMarshalling="true"/>

Modified: core/trunk/src/test/resources/configs/string-property-replaced.xml
===================================================================
--- core/trunk/src/test/resources/configs/string-property-replaced.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/configs/string-property-replaced.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="urn:jboss:jbosscache-core:config:3.2">
 
    <locking lockAcquisitionTimeout="${test.property.LockAcquisitionTimeout:15000}"
             nodeLockingScheme="${test.property.NodeLockingScheme:MVCC}"/>

Modified: core/trunk/src/test/resources/jbc3-registry-configs.xml
===================================================================
--- core/trunk/src/test/resources/jbc3-registry-configs.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/jbc3-registry-configs.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<registry:cache-configs xmlns="urn:jboss:jbosscache-core:config:3.1" xmlns:registry="urn:jboss:jbosscache-core:cache-repo:3.1">
+<registry:cache-configs xmlns="urn:jboss:jbosscache-core:config:3.2" xmlns:registry="urn:jboss:jbosscache-core:cache-repo:3.2">
 
     <!--
      Various JBoss Cache configurations, suitable for different caching

Modified: core/trunk/src/test/resources/unit-test-cache-service.xml
===================================================================
--- core/trunk/src/test/resources/unit-test-cache-service.xml	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/test/resources/unit-test-cache-service.xml	2009-08-07 10:03:27 UTC (rev 8165)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 
-<jbosscache xmlns="urn:jboss:jbosscache-core:config:3.1">
+<jbosscache xmlns="urn:jboss:jbosscache-core:config:3.2">
    <locking isolationLevel="REPEATABLE_READ" lockAcquisitionTimeout="10000"/>
    <transaction transactionManagerLookupClass="org.jboss.cache.transaction.GenericTransactionManagerLookup"/>
    <serialization useRegionBasedMarshalling="false"/>



More information about the jbosscache-commits mailing list
--- core/trunk/src/main/java/org/jboss/cache/config/parsing/RootElementBuilder.java	2009-08-07 09:27:48 UTC (rev 8164)
+++ core/trunk/src/main/java/org/jboss/cache/config/parsing/RootElementBuilder.java	2009-08-07 10:03:27 UTC (rev 8165)
@@ -34,10 +34,13 @@
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import java.io.InputStream;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.ArrayList;
 
 /**
- * Parses an xml files and validates xml elements form {@link RootElementBuilder#JBOSSCACHE_CORE_NS_31} namespace
- * according to the configured schema.
+ * Parses an xml files and validates xml elements.
  *
  * @author Mircea.Markus at jboss.com
  * @since 3.0
@@ -47,18 +50,25 @@
 
    private static final JBossEntityResolver resolver = new JBossEntityResolver();
 
-   public static final String JBOSSCACHE_CORE_NS_31 = "urn:jboss:jbosscache-core:config:3.1";
-   public static final String JBOSSCACHE_REPO_NS_31 = "urn:jboss:jbosscache-core:cache-repo:3.1";
-   public static final String JBOSSCACHE_CORE_NS_30 = "urn:jboss:jbosscache-core:config:3.0";
-   public static final String JBOSSCACHE_REPO_NS_30 = "urn:jboss:jbosscache-core:cache-repo:3.0";
+   public static final Map<String, String> ALLOWED_CORE_NAMESPACES = new HashMap<String, String>(4, 1f);
+   public static final Map<String, String> ALLOWED_REPO_NAMESPACES = new HashMap<String, String>(4, 1f);
 
+   public static final String DEFAULT_CORE_NS = "urn:jboss:jbosscache-core:config:3.2";
+   public static final String DEFAULT_REPO_NS = "urn:jboss:jbosscache-core:cache-repo:3.2";
+
    static
    {
-      // Globally register this namespace
-      JBossEntityResolver.registerEntity(JBOSSCACHE_CORE_NS_31, "jbosscache-config-3.1.xsd");
-      JBossEntityResolver.registerEntity(JBOSSCACHE_REPO_NS_31, "jbosscache-registry-3.1.xsd");
-      JBossEntityResolver.registerEntity(JBOSSCACHE_CORE_NS_30, "jbosscache-config-3.0.xsd");
-      JBossEntityResolver.registerEntity(JBOSSCACHE_REPO_NS_30, "jbosscache-registry-3.0.xsd");
+      ALLOWED_CORE_NAMESPACES.put("urn:jboss:jbosscache-core:config:3.2", "jbosscache-config-3.2.xsd");
+      ALLOWED_CORE_NAMESPACES.put("urn:jboss:jbosscache-core:config:3.1", "jbosscache-config-3.1.xsd");
+      ALLOWED_CORE_NAMESPACES.put("urn:jboss:jbosscache-core:config:3.0", "jbosscache-config-3.0.xsd");
+
+      ALLOWED_REPO_NAMESPACES.put("urn:jboss:jbosscache-core:cache-repo:3.2", "jbosscache-registry-3.2.xsd");
+      ALLOWED_REPO_NAMESPACES.put("urn:jboss:jbosscache-core:cache-repo:3.1", "jbosscache-registry-3.1.xsd");
+      ALLOWED_REPO_NAMESPACES.put("urn:jboss:jbosscache-core:cache-repo:3.0", "jbosscache-registry-3.0.xsd");
+
+      // Globally register the namespaces
+      for (Map.Entry<String, String> entry: ALLOWED_CORE_NAMESPACES.entrySet()) JBossEntityResolver.registerEntity(entry.getKey(), entry.getValue());
+      for (Map.Entry<String, String> entry: ALLOWED_REPO_NAMESPACES.entrySet()) JBossEntityResolver.registerEntity(entry.getKey(), entry.getValue());
    }
 
    private static final Log log = LogFactory.getLog(RootElementBuilder.class);
@@ -87,6 +97,14 @@
    {
       this(new FailureErrorHandler(), validating);
    }
+
+   private String[] namespaces()
+   {
+      List<String> ns = new ArrayList<String>(ALLOWED_CORE_NAMESPACES.size() + ALLOWED_REPO_NAMESPACES.size());
+      for (String candidate: ALLOWED_CORE_NAMESPACES.keySet()) ns.add(candidate);
+      for (String candidate: ALLOWED_REPO_NAMESPACES.keySet()) ns.add(candidate);
+      return ns.toArray(new String[ns.size()]);
+   }
  
    public Element readRoot(InputStream config)
    {
@@ -98,8 +116,7 @@
          {
             docBuilderFactory.setValidating(true);
             docBuilderFactory.setAttribute("http://java.sun.com/xml/jaxp/properties/schemaLanguage", "http://www.w3.org/2001/XMLSchema");
-            docBuilderFactory.setAttribute("http://java.sun.com/xml/jaxp/properties/schemaSource",
-                  new String[]{JBOSSCACHE_CORE_NS_30, JBOSSCACHE_CORE_NS_31, JBOSSCACHE_REPO_NS_30, JBOSSCACHE_REPO_NS_31});
+            docBuilderFactory.setAttribute("http://java.sun.com/xml/jaxp/properties/schemaSource", namespaces());
          }
          DocumentBuilder parser = docBuilderFactory.newDocumentBuilder();
          parser.setEntityResolver(resolver);

Modified: core/trunk/src/main/java/org/jboss/cache/config/parsing/XmlConfigHelper.java
===================================================================